==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteActionRewritePrefixArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property defaultPrefix Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
 * @property value Value used to replace the incoming route prefix when rewritten.
 */
public data class GatewayRouteSpecHttpRouteActionRewritePrefixArgs(
    public val defaultPrefix: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs.builder()
            .defaultPrefix(defaultPrefix?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteActionRewritePrefixArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteActionRewritePrefixArgsBuilder internal constructor() {
    private var defaultPrefix: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("vrlerxwdgdldblle")
    public suspend fun defaultPrefix(`value`: Output<String>) {
        this.defaultPrefix = value
    }

    /**
     * @param value Value used to replace the incoming route prefix when rewritten.
     */
    @JvmName("yhhrajpxxyktymtv")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("gnpjbfkjmnrqssrk")
    public suspend fun defaultPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultPrefix = mapped
    }

    /**
     * @param value Value used to replace the incoming route prefix when rewritten.
     */
    @JvmName("wvgqthxjjtikrmxu")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteActionRewritePrefixArgs =
        GatewayRouteSpecHttpRouteActionRewritePrefixArgs(
            defaultPrefix = defaultPrefix,
            `value` = `value`,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecHttpRouteActionRewritePrefixArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property defaultPrefix Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
 * @property value Value used to replace the incoming route prefix when rewritten.
 */
public data class GatewayRouteSpecHttpRouteActionRewritePrefixArgs(
    public val defaultPrefix: Output<String>? = null,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecHttpRouteActionRewritePrefixArgs.builder()
            .defaultPrefix(defaultPrefix?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecHttpRouteActionRewritePrefixArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecHttpRouteActionRewritePrefixArgsBuilder internal constructor() {
    private var defaultPrefix: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("hxpqvnaglsvqnntk")
    public suspend fun defaultPrefix(`value`: Output<String>) {
        this.defaultPrefix = value
    }

    /**
     * @param value Value used to replace the incoming route prefix when rewritten.
     */
    @JvmName("jhfyrjtjxepnoinn")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Default prefix used to replace the incoming route prefix when rewritten. Valid values: `ENABLED`, `DISABLED`.
     */
    @JvmName("lhnbpdrmpkgmceml")
    public suspend fun defaultPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultPrefix = mapped
    }

    /**
     * @param value Value used to replace the incoming route prefix when rewritten.
     */
    @JvmName("rcrhglfmtkrsflkl")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): GatewayRouteSpecHttpRouteActionRewritePrefixArgs =
        GatewayRouteSpecHttpRouteActionRewritePrefixArgs(
            defaultPrefix = defaultPrefix,
            `value` = `value`,
        )
}
